@@ -6,7 +6,7 @@ package DBIx::Class::Smooth::ResultSetBase;
 
 # ABSTRACT: Short intro
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.0105';
+our $VERSION = '0.0106';
 
 use parent 'DBIx::Class::ResultSet';
 use List::SomeUtils qw/any/;
@@ -82,6 +82,18 @@ sub filterattr($self, %args) {
     return $self->search({}, \%args);
 }
 
+# $rs->annotate(point_x => X('location'));
+sub annotate($self, $getter_name, $function_structure, $as = undef) {
+    if ($as) {
+        $function_structure->{'-as'} = $as;
+    }
+    my $structure = {
+        '+select' => [$function_structure],
+        '+as' => [$getter_name],
+    };
+    return $self->search({}, $structure);
+}
+
 1;
 
 __END__
@@ -96,7 +108,7 @@ DBIx::Class::Smooth::ResultSetBase - Short intro
 
 =head1 VERSION
 
-Version 0.0105, released 2020-09-20.
+Version 0.0106, released 2020-10-28.
 
 =head1 SOURCE
 
